@@ -30,39 +30,6 @@ _fname_db = 'db.optzer.json'
 def gauss_kernel(x):
     return np.exp(-0.5*x*x)/np.sqrt(2.0*np.pi)
 
-class Sample:
-    """
-    A sample point that has parameter vector and loss value.
-    """
-    def __init__(self, iid, ndim, loss_func):
-        self.iid = iid
-        self.ndim = ndim
-        self.loss_func = loss_func
-        self.variables = np.zeros(self.ndim)
-        self.val = None
-        return None
-
-    def set_variables(self,variables):
-        if len(variables) != len(self.variables):
-            raise ValueError('len(variables) != len(self.variables)')
-
-        self.variables[:] = variables[:]
-        self.val = None
-        return None
-
-    def calc_loss_func(self, vlogs, **kwargs):
-        """
-        Compute loss function value using self.loss_func function given in the constructor.
-        """
-        vec = copy.copy(self.variables)
-        # If vlog != None, some of variables may be expressed in log domain,
-        # they must be transformed back to non-log domain.
-        for i in range(len(vec)):
-            if vlogs[i]:
-                vec[i] = np.exp(vec[i])
-        val = self.loss_func(vec, **kwargs)
-        return val,kwargs['index']
-
 class TPE:
     """
     Class for Tree-based Parzen Estimator (TPE) or Weighted Parzen Estimator (WPE).
@@ -164,7 +131,7 @@ class TPE:
                 print(e)
                 print(f'\n !!! Failed to load {_fname_db} for restart. !!!'
                       +'\n !!! So start with the given initial guess.     !!!')
-            print(f'\n Restarting with existing DB, {_fname_db}.')
+            print(f'\n Restarting with existing DB, {_fname_db}.\n')
 
         #...Initialize sample history
         self.candidates = []
@@ -186,9 +153,12 @@ class TPE:
             self.bestsmpl = ind_from_db(self.history_db,
                                         bestidx,
                                         self.vnames, self.slims)
+            self.slims = update_slims(self.slims, self.hlims,
+                                      self.history_db,
+                                      ntops=max(100,int(len(self.history_db)*self.gamma)))
             #...Generate random population with the updated slims
-            self.iidinc = int(self.history_db.iid.max()) +1
-            self.igen0 = int(self.history_db.gen.max()) +1
+            self.iidinc = self.history_db.iid.max() +1
+            self.igen0 = self.history_db.gen.max() +1
             for i in range(self.nbatch):
                 ind = Individual(self.iidinc, self.vnames)
                 ind.init_random(self.slims)
@@ -286,7 +256,7 @@ class TPE:
             for res in results:
                 loss, i = res
                 self.candidates[i].loss = loss
-                self.candidates[i].gen = igen+1
+                self.candidates[i].gen = igen
             db_add = [ c.to_DataFrame() for c in self.candidates ]
             self.history_db = pd.concat([self.history_db] +db_add)
             self.history_db.drop_duplicates(subset='iid',
@@ -318,18 +288,18 @@ class TPE:
         return None
 
     def _write_step_info(self,istp,starttime):
-        print(' step,time,best_iid,best_loss,vars='
+        print(' step,time,best_iid,best_loss='
               +' {0:6d} {1:8.1f} {2:5d} {3:8.4f}'.format(istp,
                                                          time()-starttime,
                                                          self.bestsmpl.iid,
                                                          self.bestsmpl.loss),end="")
-        inc = 0
-        for k in self.vnames:
-            if inc < 16:
-                print(' {0:6.3f}'.format(self.bestsmpl.vs[k]),end="")
-            else:
-                break
-            inc += 1
+        # inc = 0
+        # for k in self.vnames:
+        #     if inc < 16:
+        #         print(' {0:6.3f}'.format(self.bestsmpl.vs[k]),end="")
+        #     else:
+        #         break
+        #     inc += 1
         print('', flush=True)
         return None
 
